package com.yunzhi.gnyy.controller;

import com.yunzhi.gnyy.common.*;
import com.yunzhi.gnyy.entity.SysSetting;
import com.yunzhi.gnyy.entity.TaPerson;
import com.yunzhi.gnyy.entity.WxUser;
import com.yunzhi.gnyy.service.ISysSettingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.gnyy.service.ITaPersonService;

import java.time.LocalDateTime;

/**
 * <p>
    * 人员表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-05-06
 */

@Api(tags = "人员表")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public HttpUtils httpUtils;

    @Autowired
    public ISysSettingService iSysSettingService;


//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }
//
//    /**
//     * 保存对象
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.save(taPerson)){
//            return ResponseBean.success(taPerson);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPersonService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
    /**
     * 修改对象
     * @param id  实体ID
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/wx/{clientId}/person",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPersonUpdate(@ApiParam("更新内容") @RequestBody TaPerson taPerson) throws Exception{

        // TODO 暂未校验 taPerson 各个必填字段

        WxUser wxUser = currentWxUser();
        if (StringUtils.isEmpty(wxUser.getPersonId())) {
            taPerson.setPersonId(null);
            iTaPersonService.save(taPerson);
            wxUser.setPersonId(taPerson.getPersonId());
            iWxUserService.updateById(wxUser);
        } else {
            taPerson.setPersonId(wxUser.getPersonId());
            iTaPersonService.updateById(taPerson);
        }

        return ResponseBean.success(taPerson);
    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaPersonService.getById(id));
//    }

    /**
     * 获取条码
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/{clientId}/person/{id}/barcode",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getBarCode(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaPerson taPerson = iTaPersonService.getById(id);
        if (null == taPerson || taPerson.getStatus() == Constants.STATUS_DELETE) {
            return ResponseBean.error("人员不存在");
        }

        String today = DateUtils.toString(LocalDateTime.now(), "yyyy-MM-dd");

        SysSetting sysSetting = iSysSettingService.getById(Constants.SETTING_BARCODE_URL);
        String url = String.format("%s?createDate=%s&idNo=%s",
                sysSetting.getContent(),
                StringUtils.urlEncode(today),
                StringUtils.urlEncode(taPerson.getIdNo()));

        return ResponseBean.success(httpUtils.get(url));
    }
}
